==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_entities/kitsession_001/KitSession.java <==

package net.datastream.schemas.mp_entities.kitsession_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITCOUNT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTDESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAXAVAILABLEKITS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTEXPIREDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dbsessionid",
    "partid",
    "storeid",
    "binid",
    "kitcount",
    "lotdescription",
    "maxavailablekits",
    "lotexpiredate"
})
@XmlRootElement(name = "KitSession")
public class KitSession {

    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "BINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type binid;
    @XmlElement(name = "KITCOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY kitcount;
    @XmlElement(name = "LOTDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String lotdescription;
    @XmlElement(name = "MAXAVAILABLEKITS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY maxavailablekits;
    @XmlElement(name = "LOTEXPIREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME lotexpiredate;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Obtient la valeur de la propriété partid.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Définit la valeur de la propriété partid.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété binid.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getBINID() {
        return binid;
    }

    /**
     * Définit la valeur de la propriété binid.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setBINID(BINID_Type value) {
        this.binid = value;
    }

    /**
     * Obtient la valeur de la propriété kitcount.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKITCOUNT() {
        return kitcount;
    }

    /**
     * Définit la valeur de la propriété kitcount.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKITCOUNT(QUANTITY value) {
        this.kitcount = value;
    }

    /**
     * Obtient la valeur de la propriété lotdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOTDESCRIPTION() {
        return lotdescription;
    }

    /**
     * Définit la valeur de la propriété lotdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOTDESCRIPTION(String value) {
        this.lotdescription = value;
    }

    /**
     * Obtient la valeur de la propriété maxavailablekits.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getMAXAVAILABLEKITS() {
        return maxavailablekits;
    }

    /**
     * Définit la valeur de la propriété maxavailablekits.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setMAXAVAILABLEKITS(QUANTITY value) {
        this.maxavailablekits = value;
    }

    /**
     * Obtient la valeur de la propriété lotexpiredate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getLOTEXPIREDATE() {
        return lotexpiredate;
    }

    /**
     * Définit la valeur de la propriété lotexpiredate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setLOTEXPIREDATE(DATETIME value) {
        this.lotexpiredate = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_entities/kitsession_001/KitSession.java <==

package net.datastream.schemas.mp_entities.kitsession_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}BINID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}KITCOUNT"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTDESCRIPTION"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAXAVAILABLEKITS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTEXPIREDATE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "dbsessionid",
    "partid",
    "storeid",
    "binid",
    "kitcount",
    "lotdescription",
    "maxavailablekits",
    "lotexpiredate"
})
@XmlRootElement(name = "KitSession")
public class KitSession {

    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY dbsessionid;
    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected STOREID_Type storeid;
    @XmlElement(name = "BINID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type binid;
    @XmlElement(name = "KITCOUNT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected QUANTITY kitcount;
    @XmlElement(name = "LOTDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected String lotdescription;
    @XmlElement(name = "MAXAVAILABLEKITS", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY maxavailablekits;
    @XmlElement(name = "LOTEXPIREDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME lotexpiredate;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the storeid property.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Sets the value of the storeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Gets the value of the binid property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getBINID() {
        return binid;
    }

    /**
     * Sets the value of the binid property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setBINID(BINID_Type value) {
        this.binid = value;
    }

    /**
     * Gets the value of the kitcount property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getKITCOUNT() {
        return kitcount;
    }

    /**
     * Sets the value of the kitcount property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setKITCOUNT(QUANTITY value) {
        this.kitcount = value;
    }

    /**
     * Gets the value of the lotdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLOTDESCRIPTION() {
        return lotdescription;
    }

    /**
     * Sets the value of the lotdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLOTDESCRIPTION(String value) {
        this.lotdescription = value;
    }

    /**
     * Gets the value of the maxavailablekits property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getMAXAVAILABLEKITS() {
        return maxavailablekits;
    }

    /**
     * Sets the value of the maxavailablekits property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setMAXAVAILABLEKITS(QUANTITY value) {
        this.maxavailablekits = value;
    }

    /**
     * Gets the value of the lotexpiredate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getLOTEXPIREDATE() {
        return lotexpiredate;
    }

    /**
     * Sets the value of the lotexpiredate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setLOTEXPIREDATE(DATETIME value) {
        this.lotexpiredate = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
